---
title: <span class="badge object-type-scalar"></span> CountsPerSecond
---
# <span class="badge object-type-scalar"></span> CountsPerSecond

Throughput: counts/sec (cps)

## Definition

```python
# Throughput: counts/sec (cps)
CountsPerSecond: typing.Literal["cps"] = "cps"
```
